==> parcel-bundler-vue-1.6.3.tgz: package/lib/utils/config.js <==
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _getIterator2 = require('babel-runtime/core-js/get-iterator');

var _getIterator3 = _interopRequireDefault(_getIterator2);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _map = require('babel-runtime/core-js/map');

var _map2 = _interopRequireDefault(_map);

var resolve = function () {
  var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(filepath, filenames) {
    var root = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : path.parse(filepath).root;

    var _iteratorNormalCompletion, _didIteratorError, _iteratorError, _iterator, _step, filename, file, exists;

    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            filepath = path.dirname(filepath);

            // Don't traverse above the module root

            if (!(filepath === root || path.basename(filepath) === 'node_modules')) {
              _context.next = 3;
              break;
            }

            return _context.abrupt('return', null);

          case 3:
            _iteratorNormalCompletion = true;
            _didIteratorError = false;
            _iteratorError = undefined;
            _context.prev = 6;
            _iterator = (0, _getIterator3.default)(filenames);

          case 8:
            if (_iteratorNormalCompletion = (_step = _iterator.next()).done) {
              _context.next = 25;
              break;
            }

            filename = _step.value;
            file = path.join(filepath, filename);

            if (!existsCache.has(file)) {
              _context.next = 15;
              break;
            }

            _context.t0 = existsCache.get(file);
            _context.next = 18;
            break;

          case 15:
            _context.next = 17;
            return fs.exists(file);

          case 17:
            _context.t0 = _context.sent;

          case 18:
            exists = _context.t0;

            if (!exists) {
              _context.next = 22;
              break;
            }

            existsCache.set(file, true);
            return _context.abrupt('return', file);

          case 22:
            _iteratorNormalCompletion = true;
            _context.next = 8;
            break;

          case 25:
            _context.next = 31;
            break;

          case 27:
            _context.prev = 27;
            _context.t1 = _context['catch'](6);
            _didIteratorError = true;
            _iteratorError = _context.t1;

          case 31:
            _context.prev = 31;
            _context.prev = 32;

            if (!_iteratorNormalCompletion && _iterator.return) {
              _iterator.return();
            }

          case 34:
            _context.prev = 34;

            if (!_didIteratorError) {
              _context.next = 37;
              break;
            }

            throw _iteratorError;

          case 37:
            return _context.finish(34);

          case 38:
            return _context.finish(31);

          case 39:
            return _context.abrupt('return', resolve(filepath, filenames, root));

          case 40:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, this, [[6, 27, 31, 39], [32,, 34, 38]]);
  }));

  return function resolve(_x2, _x3) {
    return _ref.apply(this, arguments);
  };
}();

var load = function () {
  var _ref2 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee2(filepath, filenames) {
    var root = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : path.parse(filepath).root;
    var configFile, extname, configStream, parse;
    return _regenerator2.default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.next = 2;
            return resolve(filepath, filenames, root);

          case 2:
            configFile = _context2.sent;

            if (!configFile) {
              _context2.next = 21;
              break;
            }

            _context2.prev = 4;
            extname = path.extname(configFile).slice(1);

            if (!(extname === 'js')) {
              _context2.next = 8;
              break;
            }

            return _context2.abrupt('return', require(configFile));

          case 8:
            _context2.next = 10;
            return fs.readFile(configFile);

          case 10:
            configStream = _context2.sent;
            parse = PARSERS[extname] || PARSERS.json;
            return _context2.abrupt('return', parse(configStream.toString()));

          case 15:
            _context2.prev = 15;
            _context2.t0 = _context2['catch'](4);

            if (!(_context2.t0.code === 'MODULE_NOT_FOUND' || _context2.t0.code === 'ENOENT')) {
              _context2.next = 20;
              break;
            }

            existsCache.delete(configFile);
            return _context2.abrupt('return', null);

          case 20:
            throw _context2.t0;

          case 21:
            return _context2.abrupt('return', null);

          case 22:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, this, [[4, 15]]);
  }));

  return function load(_x6, _x7) {
    return _ref2.apply(this, arguments);
  };
}();

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var fs = require('./fs');
var path = require('path');

var PARSERS = {
  json: require('json5').parse,
  toml: require('toml').parse
};

var existsCache = new _map2.default();

function resolveSync(filepath, filenames) {
  var root = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : path.parse(filepath).root;

  filepath = path.dirname(filepath);

  // Don't traverse above the module root
  if (filepath === root || path.basename(filepath) === 'node_modules') {
    return null;
  }

  var _iteratorNormalCompletion2 = true;
  var _didIteratorError2 = false;
  var _iteratorError2 = undefined;

  try {
    for (var _iterator2 = (0, _getIterator3.default)(filenames), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
      var filename = _step2.value;

      var file = path.join(filepath, filename);
      var exists = existsCache.has(file) ? existsCache.get(file) : fs.existsSync(file);
      if (exists) {
        existsCache.set(file, true);
        return file;
      }
    }
  } catch (err) {
    _didIteratorError2 = true;
    _iteratorError2 = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion2 && _iterator2.return) {
        _iterator2.return();
      }
    } finally {
      if (_didIteratorError2) {
        throw _iteratorError2;
      }
    }
  }

  return resolveSync(filepath, filenames, root);
}

exports.resolve = resolve;
exports.resolveSync = resolveSync;
exports.load = load;

==> parcel-bundler-vue-2.0.0.tgz: package/lib/utils/config.js <==
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _getIterator2 = require('babel-runtime/core-js/get-iterator');

var _getIterator3 = _interopRequireDefault(_getIterator2);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _map = require('babel-runtime/core-js/map');

var _map2 = _interopRequireDefault(_map);

var resolve = function () {
  var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(filepath, filenames) {
    var root = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : path.parse(filepath).root;

    var _iteratorNormalCompletion, _didIteratorError, _iteratorError, _iterator, _step, filename, file, exists;

    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            filepath = path.dirname(filepath);

            // Don't traverse above the module root

            if (!(filepath === root || path.basename(filepath) === 'node_modules')) {
              _context.next = 3;
              break;
            }

            return _context.abrupt('return', null);

          case 3:
            _iteratorNormalCompletion = true;
            _didIteratorError = false;
            _iteratorError = undefined;
            _context.prev = 6;
            _iterator = (0, _getIterator3.default)(filenames);

          case 8:
            if (_iteratorNormalCompletion = (_step = _iterator.next()).done) {
              _context.next = 25;
              break;
            }

            filename = _step.value;
            file = path.join(filepath, filename);

            if (!existsCache.has(file)) {
              _context.next = 15;
              break;
            }

            _context.t0 = existsCache.get(file);
            _context.next = 18;
            break;

          case 15:
            _context.next = 17;
            return fs.exists(file);

          case 17:
            _context.t0 = _context.sent;

          case 18:
            exists = _context.t0;

            if (!exists) {
              _context.next = 22;
              break;
            }

            existsCache.set(file, true);
            return _context.abrupt('return', file);

          case 22:
            _iteratorNormalCompletion = true;
            _context.next = 8;
            break;

          case 25:
            _context.next = 31;
            break;

          case 27:
            _context.prev = 27;
            _context.t1 = _context['catch'](6);
            _didIteratorError = true;
            _iteratorError = _context.t1;

          case 31:
            _context.prev = 31;
            _context.prev = 32;

            if (!_iteratorNormalCompletion && _iterator.return) {
              _iterator.return();
            }

          case 34:
            _context.prev = 34;

            if (!_didIteratorError) {
              _context.next = 37;
              break;
            }

            throw _iteratorError;

          case 37:
            return _context.finish(34);

          case 38:
            return _context.finish(31);

          case 39:
            return _context.abrupt('return', resolve(filepath, filenames, root));

          case 40:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, this, [[6, 27, 31, 39], [32,, 34, 38]]);
  }));

  return function resolve(_x2, _x3) {
    return _ref.apply(this, arguments);
  };
}();

var load = function () {
  var _ref2 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee2(filepath, filenames) {
    var root = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : path.parse(filepath).root;
    var configFile, configStream;
    return _regenerator2.default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.next = 2;
            return resolve(filepath, filenames, root);

          case 2:
            configFile = _context2.sent;

            if (!configFile) {
              _context2.next = 19;
              break;
            }

            _context2.prev = 4;

            if (!(path.extname(configFile) === '.js')) {
              _context2.next = 7;
              break;
            }

            return _context2.abrupt('return', require(configFile));

          case 7:
            _context2.next = 9;
            return fs.readFile(configFile);

          case 9:
            configStream = _context2.sent;
            return _context2.abrupt('return', json5.parse(configStream.toString()));

          case 13:
            _context2.prev = 13;
            _context2.t0 = _context2['catch'](4);

            if (!(_context2.t0.code === 'MODULE_NOT_FOUND' || _context2.t0.code === 'ENOENT')) {
              _context2.next = 18;
              break;
            }

            existsCache.delete(configFile);
            return _context2.abrupt('return', null);

          case 18:
            throw _context2.t0;

          case 19:
            return _context2.abrupt('return', null);

          case 20:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, this, [[4, 13]]);
  }));

  return function load(_x6, _x7) {
    return _ref2.apply(this, arguments);
  };
}();

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var fs = require('./fs');
var path = require('path');
var json5 = require('json5');

var existsCache = new _map2.default();

function resolveSync(filepath, filenames) {
  var root = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : path.parse(filepath).root;

  filepath = path.dirname(filepath);

  // Don't traverse above the module root
  if (filepath === root || path.basename(filepath) === 'node_modules') {
    return null;
  }

  var _iteratorNormalCompletion2 = true;
  var _didIteratorError2 = false;
  var _iteratorError2 = undefined;

  try {
    for (var _iterator2 = (0, _getIterator3.default)(filenames), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
      var filename = _step2.value;

      var file = path.join(filepath, filename);
      var exists = existsCache.has(file) ? existsCache.get(file) : fs.existsSync(file);
      if (exists) {
        existsCache.set(file, true);
        return file;
      }
    }
  } catch (err) {
    _didIteratorError2 = true;
    _iteratorError2 = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion2 && _iterator2.return) {
        _iterator2.return();
      }
    } finally {
      if (_didIteratorError2) {
        throw _iteratorError2;
      }
    }
  }

  return resolveSync(filepath, filenames, root);
}

exports.resolve = resolve;
exports.resolveSync = resolveSync;
exports.load = load;
